package
Version:
v0.32.59
Opens a new window with list of versions in this module.
Published: May 14, 2026
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
IsFlagError returns true if the error looks like a CLI flag parsing error.
type ExitError struct {
Code int
Err error
}
ExitError wraps an error with a process exit code.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.