package
Version:
v0.6.0
Opens a new window with list of versions in this module.
Published: Mar 20, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Options struct {
Now func() time.Time
}
type Report struct {
ProjectID string `json:"project_id"`
Topic string `json:"topic"`
Path string `json:"path"`
CreatedAt time.Time `json:"created_at"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.