cli

package
v0.32.17 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 9, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsFlagError

func IsFlagError(err error) bool

IsFlagError returns true if the error looks like a CLI flag parsing error.

Types

type ExitError

type ExitError struct {
	Code int
	Err  error
}

ExitError wraps an error with a process exit code.

func (*ExitError) Error

func (e *ExitError) Error() string

Jump to